##############################################################################
# 
# Zope Public License (ZPL) Version 1.0
# -------------------------------------
# 
# Copyright (c) Digital Creations.  All rights reserved.
# 
# This license has been certified as Open Source(tm).
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
# 
# 1. Redistributions in source code must retain the above copyright
#    notice, this list of conditions, and the following disclaimer.
# 
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions, and the following disclaimer in
#    the documentation and/or other materials provided with the
#    distribution.
# 
# 3. Digital Creations requests that attribution be given to Zope
#    in any manner possible. Zope includes a "Powered by Zope"
#    button that is installed by default. While it is not a license
#    violation to remove this button, it is requested that the
#    attribution remain. A significant investment has been put
#    into Zope, and this effort will continue if the Zope community
#    continues to grow. This is one way to assure that growth.
# 
# 4. All advertising materials and documentation mentioning
#    features derived from or use of this software must display
#    the following acknowledgement:
# 
#      "This product includes software developed by Digital Creations
#      for use in the Z Object Publishing Environment
#      (http://www.zope.org/)."
# 
#    In the event that the product being advertised includes an
#    intact Zope distribution (with copyright and license included)
#    then this clause is waived.
# 
# 5. Names associated with Zope or Digital Creations must not be used to
#    endorse or promote products derived from this software without
#    prior written permission from Digital Creations.
# 
# 6. Modified redistributions of any form whatsoever must retain
#    the following acknowledgment:
# 
#      "This product includes software developed by Digital Creations
#      for use in the Z Object Publishing Environment
#      (http://www.zope.org/)."
# 
#    Intact (re-)distributions of any official Zope release do not
#    require an external acknowledgement.
# 
# 7. Modifications are encouraged but must be packaged separately as
#    patches to official Zope releases.  Distributions that do not
#    clearly separate the patches from the original work must be clearly
#    labeled as unofficial distributions.  Modifications which do not
#    carry the name Zope may be packaged in any form, as long as they
#    conform to all of the clauses above.
# 
# 
# Disclaimer
# 
#   THIS SOFTWARE IS PROVIDED BY DIGITAL CREATIONS ``AS IS'' AND ANY
#   EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
#   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
#   PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL DIGITAL CREATIONS OR ITS
#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
#   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
#   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
#   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
#   OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
#   SUCH DAMAGE.
# 
# 
# This software consists of contributions made by Digital Creations and
# many individuals on behalf of Digital Creations.  Specific
# attributions are listed in the accompanying credits file.
# 
##############################################################################
"""
    Patches OFS.Image.File, OFS.DTMLDocument.DTMLDocument
    and OFS.DTMLMethod.DTMLMethod, so that a "Text Convert"
    tab is available for all objects based on them.
"""
__version__ = '3.0'

import Patch
import OFS.Image
import OFS.DTMLDocument
import OFS.DTMLMethod
import Globals
from Globals import HTMLFile
import whrandom
try:
    import Products.ZStyleSheet.ZStyleSheet
    useZSS = 1
except:
    useZSS = 0

def manage_performTextConvert(self, data, convert, inplace='0', keepold='0', REQUEST=None):
    """ Attempts to perform a TextConvert operation. """
    parent = self.aq_parent
    oldName = "%s" % self.id()
    destName = "%s" % self.id()
    while hasattr(parent, destName):
        destName = "%s_%d" % (self.id(), whrandom.uniform(1000, 10000))
    if inplace!='0':
        tmpName = oldName
        oldName = destName
        destName = tmpName
        parent.manage_renameObject(destName, oldName)
    if convert == 'DTML Method':
        if (hasattr(self, 'content_type')):
            data = """<dtml-call "RESPONSE.setHeader('content-type', '%s')">\n\n%s""" % (self.content_type, self.data)
        OFS.DTMLMethod.addDTMLMethod(parent, id=destName, title=self.title, file=data)
    elif convert == 'DTML Document':
        if (hasattr(self, 'content_type')):
            data = """<dtml-call "RESPONSE.setHeader('content-type', '%s')">\n\n%s""" % (self.content_type, self.data)
        OFS.DTMLDocument.addDTMLDocument(parent, id=destName, title=self.title, file=data)
    elif useZSS and convert == 'ZStyleSheet':
        Products.ZStyleSheet.ZStyleSheet.manage_addZStyleSheet(parent, id=destName, title=self.title, file=self.data)
    else:
        raise "Conversion Error", "What did you want to convert TO?"
    if keepold=='0':
        parent.manage_delObjects([oldName])
    if REQUEST:
        if inplace=='1':
            if keepold=='0':
                message="Converted to %s called '%s' (Original deleted)" % (convert, destName)
                item=getattr(parent, destName)
            else:
                message="Converted to %s called '%s' (Original renamed to %s)" % (convert, destName, oldName)
                item=getattr(parent, oldName)
        else:
            message="Converted to %s called '%s' (Original unchanged)" % (convert, destName)
            item=getattr(parent, oldName)
        return item.manage_main(item, REQUEST, manage_tabs_message=message)
    return None

def filterTextConvertTab(obj):
    if hasattr(obj, 'content_type'):
        if (obj.content_type[:5]!='text/'):
            return 0
    return 1

def performPatch():
    """ Patch the OFS.Image.File object """
    productList = (
        OFS.Image.File,
        OFS.DTMLDocument.DTMLDocument,
        OFS.DTMLMethod.DTMLMethod
    )
    convertOptions = ['DTML Document', 'DTML Method']
    if useZSS:
        convertOptions.append('ZStyleSheet')
    newManageOptions = (
        {'label':'Text Convert', 'action':'manage_performTextConvertForm',
         'filter':filterTextConvertTab,
         'help':('PatchKit', 'TextConvert.stx'),
        },
    )
    newFuncNames = (
        'manage_performTextConvertForm',
        'manage_performTextConvert',
        'textConvertOptions',
    )
    newFuncs = (
        HTMLFile('www/textConvert', globals()),
        manage_performTextConvert,
        convertOptions
    )
    Patch._doPatch(productList, newManageOptions, newFuncNames, newFuncs)
